<?php $TRANSLATIONS = array(
"Music" => "Glasba",
"Add album to playlist" => "Dodaj album na seznam predvajanja",
"Play" => "Predvajaj",
"Pause" => "Premor",
"Previous" => "Prejšnja",
"Next" => "Naslednja",
"Mute" => "Utišaj",
"Unmute" => "Povrni glasnost",
"Rescan Collection" => "Ponovno preišči zbirko",
"Artist" => "Izvajalec",
"Album" => "Album",
"Title" => "Naslov"
);
